@@ -40,18 +40,3 @@ ipmisc::enframe
 #' @export
 #' @importFrom ipmisc as_tibble
 ipmisc::as_tibble
-
-
-# ----------------------- ipmisc -----------------------------------
-
-#' @export
-#' @importFrom ipmisc specify_decimal_p
-ipmisc::specify_decimal_p
-
-#' @export
-#' @importFrom ipmisc signif_column
-ipmisc::signif_column
-
-#' @export
-#' @importFrom ipmisc long_to_wide_converter
-ipmisc::long_to_wide_converter
